%define debug_package %{nil}
%define _use_internal_dependency_generator 0

%define	rel			3
%define	VirtualEnvironment	%{name}-%{version}-%{rel}
%define VirtualEnvironmentPath	%{_prefix}/local/lib/PythonVirtualEnvironments

%define	__find_provides		/tmp/myfind-provides
%define	__find_requires		/tmp/myfind-requires


%define	_build_id_links 	none

%if 0%{?centos} || 0%{?amzn}
%define __python		%(echo which python3 | scl enable rh-python38 -)
%else
%define	__python		/usr/bin/python3
%endif

Summary:	Mac OS Artifact Parsing Tool

Packager:	Lawrence R. Rogers (lrr@cert.org)

Vendor:		cert.org
Name:		mac_apt
Version:	1.5.0.dev
Release:	%{rel}%{?dist}
URL:		https://github.com/ydkhatri/mac_apt/wiki

License:	GPL

Group:		Applications/Forensics Tools
Source1:	%{name}-%{version}.tar.gz
Source2:	libewf-20140812.tar.gz
BuildRoot:	%{_tmppath}/rpm-root-%{name}-v%{version}
BuildRequires:	bzip2-devel kernel-headers openssl-devel
BuildRequires:	gcc-c++

%if 0%{?amzn}
BuildRequires:  rh-python36-python-virtualenv
BuildRequires:  rh-python38-python rh-python38-python-devel
BuildRequires:  rust
Requires:       rh-python38-python
%endif

%if 0%{?centos} == 8 || 0%{?rhel} == 8
BuildRequires:	python3-virtualenv python38-devel python38
%endif

%if 0%{?centos} == 9 || 0%{?rhel} == 9
BuildRequires:	python3-virtualenv python3-devel python3
%endif

%if 0%{?centos} == 7 && 0%{?amzn} == 0
BuildRequires:	python36-virtualenv
BuildRequires:	rh-python38-python rh-python38-python-devel
Requires:       rh-python38-python
%endif

%if 0%{?fedora} 
BuildRequires:	python3-virtualenv 
%if 0%{?fedora} == 37
BuildRequires:	python3.10-devel
%else
BuildRequires:	python3-devel
%endif
%endif

%description
mac_apt is a DFIR (Digital Forensics and Incident Response) tool to process Mac computer full disk images (or live machines) and extract
data/metadata useful for forensic investigation. It is a python based framework, which has plugins to process individual artifacts (such as Safari
internet history, Network interfaces, Recently accessed files & volumes, ..)

mac_apt now also includes ios_apt, for processing ios images.

Requirements: Python 3.7 or above (32/64 bit)

Features

* Cross platform (no dependency on pyobjc)
* Works on E01, VMDK, AFF4, DD, split-DD, DMG (no compression), SPARSEIMAGE & mounted images
* XLSX, CSV, TSV, Sqlite outputs
* Analyzed files/artifacts are exported for later review
* zlib, lzvn, lzfse compressed files are supported!
* Native HFS & APFS parser
* Reads the Spotlight database and Unified Logging (tracev3) files

Latest
*  Can read Axiom created targeted collection zip files
*  ios_apt can read GrayKey extracted file system
*  Can read RECON created .sparseimage files
*  Support for macOS Big Sur Sealed volumes (11.0)
*  Introducing ios_apt for processing iOS/ipadOS images
*  FAST mode 
*  Encrypted APFS images can now be processed using password/recovery-key 
*  macOS Catalina (10.15+) separately mounted SYSTEM & DATA volumes now supported
*  AFF4 images (including macquisition created) are supported

%prep
%setup -cT
sudo mkdir -p %{VirtualEnvironmentPath}
sudo chown %(id -u).%(id -g) %{VirtualEnvironmentPath}
cd %{VirtualEnvironmentPath}
rm -rf %{VirtualEnvironment}
mkdir -p %{VirtualEnvironment}

%if 0%{?amzn}
echo virtualenv -p $(echo which python3.8 | scl enable rh-python38 -) %{VirtualEnvironment} | scl enable rh-python36 -
%endif

%if 0%{?centos}0%{?amzn} == 70
echo virtualenv-3 -p $(echo which python3 | scl enable rh-python38 -) %{VirtualEnvironment} | scl enable rh-python38 -
%endif

%if 0%{?centos} == 8
virtualenv-3 -p $(which python3.8) %{VirtualEnvironment}
%endif

%if 0%{?centos} == 9
virtualenv -p $(which python3) %{VirtualEnvironment}
%endif

%if 0%{?fedora}
%if 0%{?fedora} == 37
virtualenv -p python3.10 %{VirtualEnvironment} 
%else
virtualenv %{VirtualEnvironment}
%endif
%endif

cd %{VirtualEnvironment}
#rm -rf %{name}-%{version}; tar zxf %{SOURCE1}; mv %{name}* %{name}-%{version}
rm -rf %{name}-%{version}; tar zxf %{SOURCE1}
tar zxf %{SOURCE2}
cat > %{__find_provides}  <<EOF
#!/bin/sh
grep -v /site-packages/ | /usr/lib/rpm/rpmdeps --define="_use_internal_dependency_generator 1" --provides
EOF
cat > %{__find_requires} <<EOF
#!/bin/sh
grep -v /site-packages/ | /usr/lib/rpm/rpmdeps --define="_use_internal_dependency_generator 1" --requires
EOF
chmod 755 %{__find_provides} %{__find_requires}

%build
cd %{VirtualEnvironmentPath}
sh -c "cd %{VirtualEnvironment}; source bin/activate; pip3 install --upgrade pip"
sh -c "cd %{VirtualEnvironment}; source bin/activate; pip3 install --upgrade pybindgen setuptools-rust setuptools"
sh -c "cd %{VirtualEnvironment}; source bin/activate; pip3 install %{name}-%{version}/other_dependencies/pyaff4-0.31-yk.zip; echo ignore errors"
sh -c "cd %{VirtualEnvironment}; source bin/activate; pip3 install %{name}-%{version}/other_dependencies/pyaff4-0.31-yk.zip"
sh -c "cd %{VirtualEnvironment}; source bin/activate; cd libewf*; python3 setup.py build; python3 setup.py install; cd ..; rm -rf libewf*"
sh -c "cd %{VirtualEnvironment}; source bin/activate; pip3 install anytree biplist construct==2.9.45 xlsxwriter plistutils kaitaistruct lz4 pytsk3==20170802 libvmdk-python==20181227 pycryptodome cryptography pybindgen==0.21.0 pillow pyliblzfse nska_deserialize"
if [[ $(%{VirtualEnvironment}/bin/python3 --version | awk -F.  '{print $2}') -ge 10 ]]; then
	sed -i 's/collections.MutableSet/collections.abc.MutableSet/' %{VirtualEnvironment}/lib/python*/site-packages/intervaltree/intervaltree.py
fi

%install
export QA_RPATHS=$[ 0x0001|0x0002 ]
%{__mkdir_p} %{buildroot}/%{VirtualEnvironmentPath}
cd %{VirtualEnvironmentPath}
rsync -a --sparse %{VirtualEnvironment} %{buildroot}%{VirtualEnvironmentPath}
rm -rf %{buildroot}%{VirtualEnvironmentPath}/%{VirtualEnvironment}/.gitignore

cd %{buildroot}/%{VirtualEnvironmentPath}/%{VirtualEnvironment}/bin
mkdir -p %{buildroot}/%{_bindir}
cat > %{buildroot}/%{_bindir}/mac_apt << 'EOF'
#!/bin/sh

N=$(basename $0)
MA=%{VirtualEnvironment}
VE=%{VirtualEnvironmentPath}

if [ -d $VE ]; then
	case "$N" in
	*.py)
		;;
	*)
		N=$N.py
		;;
	esac
	source $VE/$MA/bin/activate
	exec python3 $VE/$MA/%{name}-%{version}/$N "$@"
else
	echo $0 cannot be found
	exit 1
fi
EOF
for app in mac_apt.py mac_apt_artifact_only{,.py} mac_apt_mounted_sys_data{,.py}
do
	ln %{buildroot}/%{_bindir}/mac_apt %{buildroot}/%{_bindir}/$app
done

%post
sh -c "source %{VirtualEnvironmentPath}/%{VirtualEnvironment}/bin/activate; pip3 install --upgrade --force-reinstall pillow"

%files
%defattr(0644, root, root, 0755)
%attr(0755,root,root)	%{_bindir}/*
%attr(0755,root,root)	%{VirtualEnvironmentPath}/%{VirtualEnvironment}/bin/*
%{VirtualEnvironmentPath}/%{VirtualEnvironment}/data
%{VirtualEnvironmentPath}/%{VirtualEnvironment}/lib
%{VirtualEnvironmentPath}/%{VirtualEnvironment}/lib64
%{VirtualEnvironmentPath}/%{VirtualEnvironment}/LICENSE
%{VirtualEnvironmentPath}/%{VirtualEnvironment}/mac_apt-1.5.0.dev

%{VirtualEnvironmentPath}/%{VirtualEnvironment}

%changelog
* Tue Jun 14 2022 Lawrence R. Rogers <lrr@cert.org> 1.5.0.dev-1
* Release 1.5.0.dev-1
	Version 1.5.0.dev

* Sat Sep  4 2021 Lawrence R. Rogers <lrr@cert.org> 1.4.3.dev-1
* Release 1.4.3.dev-1
	Version 1.4.3.dev

* Tue Sep 22 2020 Lawrence R. Rogers <lrr@cert.org> 0.7-1
* Release 0.7-1
	Initial release into LiFTeR
	Version 0.7
